You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2011/03/20 22:22:47 UTC

svn commit: r1083574 [6/12] - in /directory: apacheds/branches/akarasulu/core-api/src/main/java/org/apache/directory/server/core/changelog/ apacheds/branches/akarasulu/core-api/src/main/java/org/apache/directory/server/core/entry/ apacheds/branches/aka...

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultEntryAttribute.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultEntryAttribute.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultModification.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultModification.java Sun Mar 20 21:22:39 2011
@@ -25,7 +25,7 @@ import java.io.ObjectOutput;
 
 import org.apache.directory.shared.i18n.I18n;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 import org.apache.directory.shared.util.Unicode;
 import org.slf4j.Logger;
@@ -75,7 +75,7 @@ public class DefaultModification impleme
         
         try
         {
-            AttributeType at = modAttribute.getAttributeType();
+            MutableAttributeTypeImpl at = modAttribute.getAttributeType();
             
             if ( at == null )
             {
@@ -240,7 +240,7 @@ public class DefaultModification impleme
         // Write the operation
         out.writeInt( operation.getValue() );
         
-        AttributeType at = attribute.getAttributeType();
+        MutableAttributeTypeImpl at = attribute.getAttributeType();
         
         // Write the attribute's oid
         Unicode.writeUTF(out, at.getOid());
@@ -270,7 +270,7 @@ public class DefaultModification impleme
         String oid = Unicode.readUTF(in);
         
         // Lookup for tha associated AttributeType
-        AttributeType attributeType = schemaManager.lookupAttributeTypeRegistry( oid );
+        MutableAttributeTypeImpl attributeType = schemaManager.lookupAttributeTypeRegistry( oid );
         
         attribute = new DefaultEntryAttribute( attributeType );
         

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Entry.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Entry.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Entry.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Entry.java Sun Mar 20 21:22:39 2011
@@ -27,7 +27,7 @@ import java.util.Set;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 
 import org.apache.directory.shared.ldap.model.name.Dn;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -117,7 +117,7 @@ public interface Entry extends Cloneable
      * @param attributeType the AttributeType we are looking for
      * @return the associated attribute
      */
-    EntryAttribute get( AttributeType attributeType );
+    EntryAttribute get( MutableAttributeTypeImpl attributeType );
 
 
     /**
@@ -125,7 +125,7 @@ public interface Entry extends Cloneable
      *
      * @return The combined set of all the attributes.
      */
-    Set<AttributeType> getAttributeTypes();
+    Set<MutableAttributeTypeImpl> getAttributeTypes();
     
     
     /**
@@ -157,7 +157,7 @@ public interface Entry extends Cloneable
      * @param attributeTypes The AttributeTypes to add.
      * @return A list of replaced Attributes, of <code>null</code> if no attribute are removed.
      */
-    List<EntryAttribute> set( AttributeType... attributeTypes );
+    List<EntryAttribute> set( MutableAttributeTypeImpl... attributeTypes );
 
 
     /**
@@ -241,7 +241,7 @@ public interface Entry extends Cloneable
      * @param values The list of binary values to inject. It can be empty.
      * @throws LdapException If the attribute does not exist
      */
-    void add( AttributeType attributeType, byte[]... values ) throws LdapException;
+    void add( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException;
 
     
     /**
@@ -262,7 +262,7 @@ public interface Entry extends Cloneable
      * @param values The list of binary values to inject. It can be empty
      * @throws org.apache.directory.shared.ldap.model.exception.LdapException If the attribute does not exist
      */
-    void add( AttributeType attributeType, String... values ) throws LdapException;
+    void add( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException;
 
     
     /**
@@ -283,7 +283,7 @@ public interface Entry extends Cloneable
      * @param values The list of binary values to inject. It can be empty
      * @throws LdapException If the attribute does not exist
      */
-    void add( AttributeType attributeType, Value<?>... values ) throws LdapException;
+    void add( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException;
 
     
     /**
@@ -305,7 +305,7 @@ public interface Entry extends Cloneable
      * @param values The list of binary values to add. It can be empty.
      * @throws LdapException If the attribute does not exist
      */
-    void add( String upId, AttributeType attributeType, byte[]... values ) throws LdapException;
+    void add( String upId, MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException;
 
     
     /**
@@ -327,7 +327,7 @@ public interface Entry extends Cloneable
      * @param values The list of binary values to add. It can be empty.
      * @throws LdapException If the attribute does not exist
      */
-    void add( String upId, AttributeType attributeType, String... values ) throws LdapException;
+    void add( String upId, MutableAttributeTypeImpl attributeType, String... values ) throws LdapException;
 
     
     /**
@@ -349,7 +349,7 @@ public interface Entry extends Cloneable
      * @param values The list of values to add. It can be empty.
      * @throws LdapException If the attribute does not exist
      */
-    void add( String upId, AttributeType attributeType, Value<?>... values ) throws LdapException;
+    void add( String upId, MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException;
 
 
     /**
@@ -422,7 +422,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws org.apache.directory.shared.ldap.model.exception.LdapException if there are failures
      */
-    EntryAttribute put( AttributeType attributeType, byte[]... values ) throws LdapException;
+    EntryAttribute put( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException;
 
 
     /**
@@ -444,7 +444,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws org.apache.directory.shared.ldap.model.exception.LdapException if there are failures
      */
-    EntryAttribute put( AttributeType attributeType, String... values ) throws LdapException;
+    EntryAttribute put( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException;
 
 
     /**
@@ -466,7 +466,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws LdapException if there are failures
      */
-    EntryAttribute put( AttributeType attributeType, Value<?>... values ) throws LdapException;
+    EntryAttribute put( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException;
 
 
     /**
@@ -491,7 +491,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws LdapException if there are failures.
      */
-    EntryAttribute put( String upId, AttributeType attributeType, byte[]... values ) throws LdapException;
+    EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException;
 
 
     /**
@@ -517,7 +517,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws org.apache.directory.shared.ldap.model.exception.LdapException if there are failures.
      */
-    EntryAttribute put( String upId, AttributeType attributeType, String... values ) throws LdapException;
+    EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, String... values ) throws LdapException;
 
 
     /**
@@ -543,7 +543,7 @@ public interface Entry extends Cloneable
      * <code>null</code>
      * @throws LdapException if there are failures.
      */
-    EntryAttribute put( String upId, AttributeType attributeType, Value<?>... values ) throws LdapException;
+    EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException;
 
 
     /**
@@ -615,7 +615,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if at least a value is removed, <code>false</code>
      * if not all the values have been removed or if the attribute does not exist. 
      */
-    boolean remove( AttributeType attributeType, byte[]... values ) throws LdapException;
+    boolean remove( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException;
 
     
     /**
@@ -639,7 +639,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if at least a value is removed, <code>false</code>
      * if not all the values have been removed or if the attribute does not exist. 
      */
-    boolean remove( AttributeType attributeType, String... values ) throws LdapException;
+    boolean remove( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException;
 
     
     /**
@@ -663,7 +663,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if at least a value is removed, <code>false</code>
      * if not all the values have been removed or if the attribute does not exist. 
      */
-    boolean remove( AttributeType attributeType, Value<?>... values ) throws LdapException;
+    boolean remove( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException;
 
     
     /**
@@ -692,7 +692,7 @@ public interface Entry extends Cloneable
      * @param attributes the AttributeTypes to be removed
      * @return the removed attributes, if any, as a list; otherwise <code>null</code>
      */
-    List<EntryAttribute> removeAttributes( AttributeType... attributes );
+    List<EntryAttribute> removeAttributes( MutableAttributeTypeImpl... attributes );
 
 
     /**
@@ -807,7 +807,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if all the values are found within the attribute,
      * <code>false</code> otherwise, or if the attributes does not exist.
      */
-    boolean contains( AttributeType attributeType, byte[]... values );
+    boolean contains( MutableAttributeTypeImpl attributeType, byte[]... values );
 
 
     /**
@@ -818,7 +818,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if all the values are found within the attribute,
      * <code>false</code> otherwise, or if the attributes does not exist.
      */
-    boolean contains( AttributeType attributeType, String... values );
+    boolean contains( MutableAttributeTypeImpl attributeType, String... values );
 
 
     /**
@@ -829,7 +829,7 @@ public interface Entry extends Cloneable
      * @return <code>true</code> if all the values are found within the attribute,
      * <code>false</code> otherwise, or if the attributes does not exist.
      */
-    boolean contains( AttributeType attributeType, Value<?>... values );
+    boolean contains( MutableAttributeTypeImpl attributeType, Value<?>... values );
 
 
     /**
@@ -838,7 +838,7 @@ public interface Entry extends Cloneable
      * @param attributeType The AttributeType to look for.
      * @return <code>true</code> if the attribute is found within the entry.
      */
-    boolean containsAttribute( AttributeType attributeType );
+    boolean containsAttribute( MutableAttributeTypeImpl attributeType );
 
     
     /**

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttribute.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttribute.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttribute.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttribute.java Sun Mar 20 21:22:39 2011
@@ -26,7 +26,7 @@ import java.util.Iterator;
 
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.exception.LdapInvalidAttributeValueException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SyntaxChecker;
 
 
@@ -207,7 +207,7 @@ public interface EntryAttribute extends 
      *
      * @return the attributeType associated with this entry attribute
      */
-    AttributeType getAttributeType();
+    MutableAttributeTypeImpl getAttributeType();
 
     
     /**
@@ -222,7 +222,7 @@ public interface EntryAttribute extends 
      *
      * @param attributeType the attributeType associated with this entry attribute
      */
-    void setAttributeType( AttributeType attributeType );
+    void setAttributeType( MutableAttributeTypeImpl attributeType );
 
     
     /**
@@ -475,7 +475,7 @@ public interface EntryAttribute extends 
      * @param upId The attribute ID
      * @param attributeType The associated attributeType
      */
-    void setUpId( String upId, AttributeType attributeType );
+    void setUpId( String upId, MutableAttributeTypeImpl attributeType );
 
     
     /**

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttributeSerializer.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttributeSerializer.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttributeSerializer.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryAttributeSerializer.java Sun Mar 20 21:22:39 2011
@@ -23,7 +23,7 @@ import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -118,7 +118,7 @@ public class EntryAttributeSerializer
             }
         }
         
-        AttributeType attributeType = null;
+        MutableAttributeTypeImpl attributeType = null;
         
         if ( schemaManager != null )
         {

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryUtils.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryUtils.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/ImmutableEntry.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/ImmutableEntry.java Sun Mar 20 21:22:39 2011
@@ -29,7 +29,7 @@ import java.util.Set;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.apache.directory.shared.util.exception.NotImplementedException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -68,7 +68,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( AttributeType attributeType, byte[]... values ) throws LdapException
+    public void add( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -78,7 +78,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( AttributeType attributeType, String... values ) throws LdapException
+    public void add( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -88,7 +88,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( AttributeType attributeType, Value<?>... values ) throws LdapException
+    public void add( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -98,7 +98,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( String upId, AttributeType attributeType, byte[]... values ) throws LdapException
+    public void add( String upId, MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -108,7 +108,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( String upId, AttributeType attributeType, Value<?>... values ) throws LdapException
+    public void add( String upId, MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -118,7 +118,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public void add( String upId, AttributeType attributeType, String... values ) throws LdapException
+    public void add( String upId, MutableAttributeTypeImpl attributeType, String... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot add an attribute : the entry " + entry.getDn() + " is immutable." );
@@ -206,7 +206,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean containsAttribute( AttributeType attributeType )
+    public boolean containsAttribute( MutableAttributeTypeImpl attributeType )
     {
         return entry.containsAttribute( attributeType );
     }
@@ -215,7 +215,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean contains( AttributeType attributeType, byte[]... values )
+    public boolean contains( MutableAttributeTypeImpl attributeType, byte[]... values )
     {
         return entry.contains( attributeType, values );
     }
@@ -224,7 +224,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean contains( AttributeType attributeType, String... values )
+    public boolean contains( MutableAttributeTypeImpl attributeType, String... values )
     {
         return entry.contains( attributeType, values );
     }
@@ -233,7 +233,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean contains( AttributeType attributeType, Value<?>... values )
+    public boolean contains( MutableAttributeTypeImpl attributeType, Value<?>... values )
     {
         return entry.contains( attributeType, values );
     }
@@ -278,7 +278,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute get( AttributeType attributeType )
+    public EntryAttribute get( MutableAttributeTypeImpl attributeType )
     {
         return entry.get( attributeType );
     }
@@ -287,7 +287,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public Set<AttributeType> getAttributeTypes()
+    public Set<MutableAttributeTypeImpl> getAttributeTypes()
     {
         return entry.getAttributeTypes();
     }
@@ -336,7 +336,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}     
      **/
-    public List<EntryAttribute> set( AttributeType... attributeTypes )
+    public List<EntryAttribute> set( MutableAttributeTypeImpl... attributeTypes )
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot set a value : the entry " + entry.getDn() + " is immutable." );
@@ -356,7 +356,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( AttributeType attributeType, byte[]... values ) throws LdapException
+    public EntryAttribute put( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -366,7 +366,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( AttributeType attributeType, String... values ) throws LdapException
+    public EntryAttribute put( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -376,7 +376,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( AttributeType attributeType, Value<?>... values ) throws LdapException
+    public EntryAttribute put( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -386,7 +386,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( String upId, AttributeType attributeType, byte[]... values ) throws LdapException
+    public EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -396,7 +396,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( String upId, AttributeType attributeType, String... values ) throws LdapException
+    public EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, String... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -406,7 +406,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public EntryAttribute put( String upId, AttributeType attributeType, Value<?>... values ) throws LdapException
+    public EntryAttribute put( String upId, MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot put a value : the entry " + entry.getDn() + " is immutable." );
@@ -426,7 +426,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean remove( AttributeType attributeType, byte[]... values ) throws LdapException
+    public boolean remove( MutableAttributeTypeImpl attributeType, byte[]... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot remove a value : the entry " + entry.getDn() + " is immutable." );
@@ -436,7 +436,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean remove( AttributeType attributeType, String... values ) throws LdapException
+    public boolean remove( MutableAttributeTypeImpl attributeType, String... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot remove a value : the entry " + entry.getDn() + " is immutable." );
@@ -446,7 +446,7 @@ public class ImmutableEntry implements E
     /**
      * {@inheritDoc}
      */
-    public boolean remove( AttributeType attributeType, Value<?>... values ) throws LdapException
+    public boolean remove( MutableAttributeTypeImpl attributeType, Value<?>... values ) throws LdapException
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot remove a value : the entry " + entry.getDn() + " is immutable." );
@@ -468,7 +468,7 @@ public class ImmutableEntry implements E
      * @param attributes the AttributeTypes to be removed
      * @return the removed attributes, if any, as a list; otherwise <code>null</code>
      */
-    public List<EntryAttribute> removeAttributes( AttributeType... attributes )
+    public List<EntryAttribute> removeAttributes( MutableAttributeTypeImpl... attributes )
     {
         new Exception().printStackTrace();
         throw new NotImplementedException( "Cannot remove a value : the entry " + entry.getDn() + " is immutable." );

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/StringValue.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/StringValue.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/StringValue.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/StringValue.java Sun Mar 20 21:22:39 2011
@@ -25,7 +25,7 @@ import java.io.ObjectOutput;
 
 import org.apache.directory.shared.i18n.I18n;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.AbstractLdapComparator;
 import org.apache.directory.shared.ldap.model.schema.Normalizer;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
@@ -70,7 +70,7 @@ public class StringValue extends Abstrac
      *
      * @param attributeType the schema type associated with this StringValue
      */
-    public StringValue( AttributeType attributeType )
+    public StringValue( MutableAttributeTypeImpl attributeType )
     {
         if ( attributeType == null )
         {
@@ -113,7 +113,7 @@ public class StringValue extends Abstrac
      * @param attributeType the schema type associated with this StringValue
      * @param value the value to wrap which can be null
      */
-    public StringValue( AttributeType attributeType, String value )
+    public StringValue( MutableAttributeTypeImpl attributeType, String value )
     {
         this( attributeType );
         this.wrappedValue = value;

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Value.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Value.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Value.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/Value.java Sun Mar 20 21:22:39 2011
@@ -23,7 +23,7 @@ package org.apache.directory.shared.ldap
 import java.io.Externalizable;
 
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.Normalizer;
 import org.apache.directory.shared.ldap.model.schema.SyntaxChecker;
 
@@ -41,7 +41,7 @@ public interface Value<T> extends Clonea
      *
      * @param attributeType The AttributeType to apply
      */
-    void apply( AttributeType attributeType );
+    void apply( MutableAttributeTypeImpl attributeType );
     
 
     /**
@@ -63,7 +63,7 @@ public interface Value<T> extends Clonea
      * 
      * @return The AttributeType
      */
-    AttributeType getAttributeType();
+    MutableAttributeTypeImpl getAttributeType();
 
     
     /**
@@ -77,7 +77,7 @@ public interface Value<T> extends Clonea
      * @return <code>true</code> if the value is associated with the given
      * attributeType or one of its ascendant
      */
-    boolean instanceOf( AttributeType attributeType ) throws LdapException;
+    boolean instanceOf( MutableAttributeTypeImpl attributeType ) throws LdapException;
 
     
     /**

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ApproximateNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ApproximateNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ApproximateNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ApproximateNode.java Sun Mar 20 21:22:39 2011
@@ -20,7 +20,7 @@
 package org.apache.directory.shared.ldap.model.filter;
 
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 /**
  * A simple assertion value node.
@@ -35,7 +35,7 @@ public class ApproximateNode<T> extends 
      * @param attributeType the attribute type
      * @param value the value to test for
      */
-    public ApproximateNode( AttributeType attributeType, Value<T> value )
+    public ApproximateNode( MutableAttributeTypeImpl attributeType, Value<T> value )
     {
         super( attributeType, value, AssertionType.APPROXIMATE );
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/EqualityNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/EqualityNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/EqualityNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/EqualityNode.java Sun Mar 20 21:22:39 2011
@@ -21,7 +21,7 @@ package org.apache.directory.shared.ldap
 
 
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -37,7 +37,7 @@ public class EqualityNode<T> extends Sim
      * @param attributeType the attributeType
      * @param value the value to test for
      */
-    public EqualityNode( AttributeType attributeType, Value<T> value )
+    public EqualityNode( MutableAttributeTypeImpl attributeType, Value<T> value )
     {
         super( attributeType, value, AssertionType.EQUALITY );
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ExtensibleNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ExtensibleNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ExtensibleNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/ExtensibleNode.java Sun Mar 20 21:22:39 2011
@@ -21,7 +21,7 @@ package org.apache.directory.shared.ldap
 
 
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -46,7 +46,7 @@ public class ExtensibleNode extends Leaf
      * 
      * @param attributeType the attributeType associated with this node
      */
-    public ExtensibleNode( AttributeType attributeType )
+    public ExtensibleNode( MutableAttributeTypeImpl attributeType )
     {
         super( attributeType, AssertionType.EXTENSIBLE );
         
@@ -75,7 +75,7 @@ public class ExtensibleNode extends Leaf
      * @param matchingRuleId the OID of the matching rule
      * @param dnAttributes the dn attributes
      */
-    public ExtensibleNode( AttributeType attributeType, Value<?> value, String matchingRuleId, boolean dnAttributes )
+    public ExtensibleNode( MutableAttributeTypeImpl attributeType, Value<?> value, String matchingRuleId, boolean dnAttributes )
     {
         super( attributeType, AssertionType.EXTENSIBLE );
 

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/FilterParser.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/FilterParser.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/FilterParser.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/FilterParser.java Sun Mar 20 21:22:39 2011
@@ -27,7 +27,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.entry.BinaryValue;
 import org.apache.directory.shared.ldap.model.entry.Value;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 import org.apache.directory.shared.util.*;
 
@@ -60,7 +60,7 @@ public class FilterParser
         
         if ( schemaManager != null )
         {
-            AttributeType attributeType = schemaManager.getAttributeType( attribute );
+            MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
             
             if ( attributeType != null )
             {
@@ -306,7 +306,7 @@ public class FilterParser
             
             if ( schemaManager != null )
             {
-                AttributeType attributeType = schemaManager.lookupAttributeTypeRegistry( attribute );
+                MutableAttributeTypeImpl attributeType = schemaManager.lookupAttributeTypeRegistry( attribute );
                 
                 if ( attributeType != null )
                 {
@@ -416,7 +416,7 @@ public class FilterParser
                 // This is a present node
                 if ( schemaManager != null )
                 {
-                    AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                    MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                     
                     if ( attributeType != null )
                     {
@@ -445,7 +445,7 @@ public class FilterParser
             // An empty equality Node
             if ( schemaManager != null )
             {
-                AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                 
                 if ( attributeType != null )
                 {
@@ -473,7 +473,7 @@ public class FilterParser
                 // This is an equality node
                 if ( schemaManager != null )
                 {
-                    AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                    MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                     
                     if ( attributeType != null )
                     {
@@ -558,7 +558,7 @@ public class FilterParser
                     }
                     else
                     {
-                        AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                        MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                         
                         if ( attributeType != null )
                         {
@@ -589,7 +589,7 @@ public class FilterParser
                     }
                     else
                     {
-                        AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                        MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                         
                         if ( attributeType != null )
                         {
@@ -620,7 +620,7 @@ public class FilterParser
                     }
                     else
                     {
-                        AttributeType attributeType = schemaManager.getAttributeType( attribute );
+                        MutableAttributeTypeImpl attributeType = schemaManager.getAttributeType( attribute );
                         
                         if ( attributeType != null )
                         {

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/GreaterEqNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/GreaterEqNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/GreaterEqNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/GreaterEqNode.java Sun Mar 20 21:22:39 2011
@@ -21,7 +21,7 @@ package org.apache.directory.shared.ldap
 
 
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -37,7 +37,7 @@ public class GreaterEqNode<T> extends Si
      * @param attributeType the attributeType
      * @param value the value to test for
      */
-    public GreaterEqNode( AttributeType attributeType, Value<T> value )
+    public GreaterEqNode( MutableAttributeTypeImpl attributeType, Value<T> value )
     {
         super( attributeType, value, AssertionType.GREATEREQ );
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LeafNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LeafNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LeafNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LeafNode.java Sun Mar 20 21:22:39 2011
@@ -19,7 +19,7 @@
  */
 package org.apache.directory.shared.ldap.model.filter;
 
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -30,7 +30,7 @@ import org.apache.directory.shared.ldap.
 public class LeafNode extends AbstractExprNode
 {
     /** attributeType on which this leaf is based */
-    protected AttributeType attributeType;
+    protected MutableAttributeTypeImpl attributeType;
     
     /** attribute on which this leaf is based */
     protected String attribute;
@@ -42,7 +42,7 @@ public class LeafNode extends AbstractEx
      * @param attributeType the attribute this node is based on
      * @param assertionType the type of this leaf node
      */
-    protected LeafNode( AttributeType attributeType, AssertionType assertionType )
+    protected LeafNode( MutableAttributeTypeImpl attributeType, AssertionType assertionType )
     {
         super( assertionType );
         this.attributeType = attributeType;
@@ -86,7 +86,7 @@ public class LeafNode extends AbstractEx
      * 
      * @return the attributeType asserted
      */
-    public final AttributeType getAttributeType()
+    public final MutableAttributeTypeImpl getAttributeType()
     {
         return attributeType;
     }
@@ -108,7 +108,7 @@ public class LeafNode extends AbstractEx
      * 
      * @param attributeType the attributeType that is asserted by this filter node
      */
-    public void setAttributeType( AttributeType attributeType )
+    public void setAttributeType( MutableAttributeTypeImpl attributeType )
     {
         this.attributeType = attributeType;
         

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LessEqNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LessEqNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LessEqNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/LessEqNode.java Sun Mar 20 21:22:39 2011
@@ -21,7 +21,7 @@ package org.apache.directory.shared.ldap
 
 
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -37,7 +37,7 @@ public class LessEqNode<T> extends Simpl
      * @param attributeType the attributeType
      * @param value the value to test for
      */
-    public LessEqNode( AttributeType attributeType, Value<T> value )
+    public LessEqNode( MutableAttributeTypeImpl attributeType, Value<T> value )
     {
         super( attributeType, value, AssertionType.LESSEQ );
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/PresenceNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/PresenceNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/PresenceNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/PresenceNode.java Sun Mar 20 21:22:39 2011
@@ -19,7 +19,7 @@
  */
 package org.apache.directory.shared.ldap.model.filter;
 
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -35,7 +35,7 @@ public final class PresenceNode extends 
      * 
      * @param attributeType the attributeType to assert the presence of
      */
-    public PresenceNode( AttributeType attributeType )
+    public PresenceNode( MutableAttributeTypeImpl attributeType )
     {
         super( attributeType, AssertionType.PRESENCE );
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SimpleNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SimpleNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SimpleNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SimpleNode.java Sun Mar 20 21:22:39 2011
@@ -23,7 +23,7 @@ package org.apache.directory.shared.ldap
 import org.apache.directory.shared.i18n.I18n;
 import org.apache.directory.shared.ldap.model.constants.SchemaConstants;
 import org.apache.directory.shared.ldap.model.entry.Value;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 
 
 /**
@@ -64,7 +64,7 @@ public abstract class SimpleNode<T> exte
      * @param value the value to test for
      * @param assertionType the type of assertion represented by this ExprNode
      */
-    protected SimpleNode( AttributeType attributeType, Value<T> value, AssertionType assertionType )
+    protected SimpleNode( MutableAttributeTypeImpl attributeType, Value<T> value, AssertionType assertionType )
     {
         super( attributeType, assertionType );
         this.value = value;

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SubstringNode.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SubstringNode.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SubstringNode.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/filter/SubstringNode.java Sun Mar 20 21:22:39 2011
@@ -27,7 +27,7 @@ import java.util.regex.PatternSyntaxExce
 
 import org.apache.directory.shared.ldap.model.entry.StringValue;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.Normalizer;
 
 
@@ -55,7 +55,7 @@ public class SubstringNode extends LeafN
      * @param initialPattern the initial fragment
      * @param finalPattern the final fragment
      */
-    public SubstringNode( AttributeType attributeType, String initialPattern, String finalPattern )
+    public SubstringNode( MutableAttributeTypeImpl attributeType, String initialPattern, String finalPattern )
     {
         super( attributeType, AssertionType.SUBSTRING );
 
@@ -88,7 +88,7 @@ public class SubstringNode extends LeafN
      * 
      * @param attribute the name of the attribute to substring assert
      */
-    public SubstringNode( AttributeType attribute )
+    public SubstringNode( MutableAttributeTypeImpl attribute )
     {
         super( attribute, AssertionType.SUBSTRING );
 
@@ -122,7 +122,7 @@ public class SubstringNode extends LeafN
      * @param initialPattern the initial fragment
      * @param finalPattern the final fragment
      */
-    public SubstringNode( List<String> anyPattern, AttributeType attributeType, String initialPattern, String finalPattern )
+    public SubstringNode( List<String> anyPattern, MutableAttributeTypeImpl attributeType, String initialPattern, String finalPattern )
     {
         super( attributeType, AssertionType.SUBSTRING );
 

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/ldif/LdifAttributesReader.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/ldif/LdifAttributesReader.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/ldif/LdifAttributesReader.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/ldif/LdifAttributesReader.java Sun Mar 20 21:22:39 2011
@@ -34,7 +34,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.entry.Entry;
 import org.apache.directory.shared.ldap.model.entry.EntryAttribute;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 import org.apache.directory.shared.util.Strings;
 import org.slf4j.Logger;
@@ -216,7 +216,7 @@ public class LdifAttributesReader extend
         int colonIndex = line.indexOf( ':' );
 
         String attributeName = lowerLine.substring( 0, colonIndex );
-        AttributeType attributeType = null;
+        MutableAttributeTypeImpl attributeType = null;
 
         // We should *not* have a Dn twice
         if ( attributeName.equals( "dn" ) )

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/SearchParams.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/SearchParams.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/SearchParams.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/message/SearchParams.java Sun Mar 20 21:22:39 2011
@@ -27,7 +27,7 @@ import javax.naming.directory.SearchCont
 
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.filter.SearchScope;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.AttributeTypeOptions;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 import org.apache.directory.shared.ldap.model.schema.SchemaUtils;
@@ -207,7 +207,7 @@ public class SearchParams
                 String id = SchemaUtils.stripOptions( returnAttribute );
                 Set<String> options = SchemaUtils.getOptions( returnAttribute );
 
-                AttributeType attributeType = schemaManager.lookupAttributeTypeRegistry( id );
+                MutableAttributeTypeImpl attributeType = schemaManager.lookupAttributeTypeRegistry( id );
                 AttributeTypeOptions attrOptions = new AttributeTypeOptions( attributeType, options );
 
                 returningAttributes.add( attrOptions );

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/name/Ava.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/name/Ava.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/name/Ava.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/name/Ava.java Sun Mar 20 21:22:39 2011
@@ -32,7 +32,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.LdapComparator;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
@@ -74,7 +74,7 @@ public final class Ava implements Extern
     private String normType;
     
     /** The attributeType if the Ava is schemaAware */
-    private AttributeType attributeType;
+    private MutableAttributeTypeImpl attributeType;
 
     /** The user provided Name type */
     private String upType;

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributeTypeOptions.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributeTypeOptions.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributeTypeOptions.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributeTypeOptions.java Sun Mar 20 21:22:39 2011
@@ -38,7 +38,7 @@ import org.apache.directory.shared.util.
 public class AttributeTypeOptions
 {
     /** The attributeType */
-    private AttributeType attributeType;
+    private MutableAttributeTypeImpl attributeType;
 
     /** The options, if any */
     private Set<String> options;
@@ -50,7 +50,7 @@ public class AttributeTypeOptions
      *
      * @param attributeType The associated AttributeType
      */
-    public AttributeTypeOptions( AttributeType attributeType )
+    public AttributeTypeOptions( MutableAttributeTypeImpl attributeType )
     {
         this.attributeType = attributeType;
     }
@@ -63,7 +63,7 @@ public class AttributeTypeOptions
      * @param attributeType the associated AttributeType
      * @param options the associated options
      */
-    public AttributeTypeOptions( AttributeType attributeType, Set<String> options )
+    public AttributeTypeOptions( MutableAttributeTypeImpl attributeType, Set<String> options )
     {
         this.attributeType = attributeType;
         this.options = options;
@@ -73,7 +73,7 @@ public class AttributeTypeOptions
     /**
      * @return the inner attributeType
      */
-    public AttributeType getAttributeType()
+    public MutableAttributeTypeImpl getAttributeType()
     {
         return attributeType;
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java Sun Mar 20 21:22:39 2011
@@ -129,19 +129,19 @@ public class DITContentRule extends Abst
     private List<String> mayAttributeTypeOids;
 
     /** The list of allowed AttributeTypes */
-    private List<AttributeType> mayAttributeTypes;
+    private List<MutableAttributeTypeImpl> mayAttributeTypes;
 
     /** The list of required AttributeType OIDs */
     private List<String> mustAttributeTypeOids;
 
     /** The list of required AttributeTypes */
-    private List<AttributeType> mustAttributeTypes;
+    private List<MutableAttributeTypeImpl> mustAttributeTypes;
 
     /** The list of precluded AttributeType OIDs */
     private List<String> notAttributeTypeOids;
 
     /** The list of precluded AttributeTypes */
-    private List<AttributeType> notAttributeTypes;
+    private List<MutableAttributeTypeImpl> notAttributeTypes;
 
 
     /**
@@ -158,9 +158,9 @@ public class DITContentRule extends Abst
         notAttributeTypeOids = new ArrayList<String>();
         auxObjectClassOids = new ArrayList<String>();
 
-        mayAttributeTypes = new ArrayList<AttributeType>();
-        mustAttributeTypes = new ArrayList<AttributeType>();
-        notAttributeTypes = new ArrayList<AttributeType>();
+        mayAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
+        mustAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
+        notAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
         auxObjectClasses = new ArrayList<ObjectClass>();
     }
 
@@ -297,7 +297,7 @@ public class DITContentRule extends Abst
      *
      * @param attributeType The attributeType
      */
-    public void addMayAttributeTypes( AttributeType attributeType )
+    public void addMayAttributeTypes( MutableAttributeTypeImpl attributeType )
     {
         if ( locked )
         {
@@ -334,7 +334,7 @@ public class DITContentRule extends Abst
      *
      * @param mayAttributeTypes the list of allowed AttributeTypes
      */
-    public void setMayAttributeTypes( List<AttributeType> mayAttributeTypes )
+    public void setMayAttributeTypes( List<MutableAttributeTypeImpl> mayAttributeTypes )
     {
         if ( locked )
         {
@@ -348,7 +348,7 @@ public class DITContentRule extends Abst
             // update the OIDS now
             mayAttributeTypeOids.clear();
 
-            for ( AttributeType may : mayAttributeTypes )
+            for ( MutableAttributeTypeImpl may : mayAttributeTypes )
             {
                 mayAttributeTypeOids.add( may.getOid() );
             }
@@ -359,7 +359,7 @@ public class DITContentRule extends Abst
     /**
      * @return the mayAttributeTypes
      */
-    public List<AttributeType> getMayAttributeTypes()
+    public List<MutableAttributeTypeImpl> getMayAttributeTypes()
     {
         return mayAttributeTypes;
     }
@@ -398,7 +398,7 @@ public class DITContentRule extends Abst
      *
      * @param attributeType The attributeType
      */
-    public void addMustAttributeTypes( AttributeType attributeType )
+    public void addMustAttributeTypes( MutableAttributeTypeImpl attributeType )
     {
         if ( locked )
         {
@@ -435,7 +435,7 @@ public class DITContentRule extends Abst
      *
      * @param mustAttributeTypes the list of required AttributeTypes
      */
-    public void setMustAttributeTypes( List<AttributeType> mustAttributeTypes )
+    public void setMustAttributeTypes( List<MutableAttributeTypeImpl> mustAttributeTypes )
     {
         if ( locked )
         {
@@ -449,7 +449,7 @@ public class DITContentRule extends Abst
             // update the OIDS now
             mustAttributeTypeOids.clear();
 
-            for ( AttributeType may : mustAttributeTypes )
+            for ( MutableAttributeTypeImpl may : mustAttributeTypes )
             {
                 mustAttributeTypeOids.add( may.getOid() );
             }
@@ -460,7 +460,7 @@ public class DITContentRule extends Abst
     /**
      * @return the mustAttributeTypes
      */
-    public List<AttributeType> getMustAttributeTypes()
+    public List<MutableAttributeTypeImpl> getMustAttributeTypes()
     {
         return mustAttributeTypes;
     }
@@ -499,7 +499,7 @@ public class DITContentRule extends Abst
      *
      * @param attributeType The attributeType
      */
-    public void addNotAttributeTypes( AttributeType attributeType )
+    public void addNotAttributeTypes( MutableAttributeTypeImpl attributeType )
     {
         if ( locked )
         {
@@ -536,7 +536,7 @@ public class DITContentRule extends Abst
      *
      * @param notAttributeTypes the list of precluded AttributeTypes
      */
-    public void setNotAttributeTypes( List<AttributeType> notAttributeTypes )
+    public void setNotAttributeTypes( List<MutableAttributeTypeImpl> notAttributeTypes )
     {
         if ( locked )
         {
@@ -550,7 +550,7 @@ public class DITContentRule extends Abst
             // update the OIDS now
             notAttributeTypeOids.clear();
 
-            for ( AttributeType not : notAttributeTypes )
+            for ( MutableAttributeTypeImpl not : notAttributeTypes )
             {
                 notAttributeTypeOids.add( not.getOid() );
             }
@@ -561,7 +561,7 @@ public class DITContentRule extends Abst
     /**
      * @return the notAttributeTypes
      */
-    public List<AttributeType> getNotAttributeTypes()
+    public List<MutableAttributeTypeImpl> getNotAttributeTypes()
     {
         return notAttributeTypes;
     }
@@ -583,7 +583,7 @@ public class DITContentRule extends Abst
 
             if ( mayAttributeTypeOids != null )
             {
-                mayAttributeTypes = new ArrayList<AttributeType>( mayAttributeTypeOids.size() );
+                mayAttributeTypes = new ArrayList<MutableAttributeTypeImpl>( mayAttributeTypeOids.size() );
 
                 for ( String oid : mayAttributeTypeOids )
                 {
@@ -593,7 +593,7 @@ public class DITContentRule extends Abst
 
             if ( mustAttributeTypeOids != null )
             {
-                mustAttributeTypes = new ArrayList<AttributeType>( mustAttributeTypeOids.size() );
+                mustAttributeTypes = new ArrayList<MutableAttributeTypeImpl>( mustAttributeTypeOids.size() );
 
                 for ( String oid : mustAttributeTypeOids )
                 {
@@ -603,7 +603,7 @@ public class DITContentRule extends Abst
 
             if ( notAttributeTypeOids != null )
             {
-                notAttributeTypes = new ArrayList<AttributeType>( notAttributeTypeOids.size() );
+                notAttributeTypes = new ArrayList<MutableAttributeTypeImpl>( notAttributeTypeOids.size() );
 
                 for ( String oid : notAttributeTypeOids )
                 {
@@ -672,7 +672,7 @@ public class DITContentRule extends Abst
         }
 
         // Clone the MAY AttributeTypes ( will be empty )
-        copy.mayAttributeTypes = new ArrayList<AttributeType>();
+        copy.mayAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
 
         // Clone the MUST AttributeTypes OIDs
         copy.mustAttributeTypeOids = new ArrayList<String>();
@@ -683,7 +683,7 @@ public class DITContentRule extends Abst
         }
 
         // Clone the MUST AttributeTypes ( will be empty )
-        copy.mustAttributeTypes = new ArrayList<AttributeType>();
+        copy.mustAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
 
         // Clone the NOT AttributeTypes OIDs
         copy.notAttributeTypeOids = new ArrayList<String>();
@@ -694,7 +694,7 @@ public class DITContentRule extends Abst
         }
 
         // Clone the NOT AttributeTypes ( will be empty )
-        copy.notAttributeTypes = new ArrayList<AttributeType>();
+        copy.notAttributeTypes = new ArrayList<MutableAttributeTypeImpl>();
 
         return copy;
     }

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java Sun Mar 20 21:22:39 2011
@@ -84,7 +84,7 @@ public final class DescriptionUtils
      * @return the AttributeTypeDescription Syntax for the attributeType in a
      *         pretty formated string
      */
-    public static String getDescription( AttributeType attributeType )
+    public static String getDescription( MutableAttributeTypeImpl attributeType )
     {
         StringBuilder buf = new StringBuilder( "( " );
         buf.append( attributeType.getOid() );
@@ -263,7 +263,7 @@ public final class DescriptionUtils
             getQDStrings( buf, aux );
         }
 
-        List<AttributeType> must = dITContentRule.getMustAttributeTypes();
+        List<MutableAttributeTypeImpl> must = dITContentRule.getMustAttributeTypes();
 
         if ( ( must != null ) && ( must.size() > 0 ) )
         {
@@ -271,7 +271,7 @@ public final class DescriptionUtils
             getQDStrings( buf, must );
         }
 
-        List<AttributeType> may = dITContentRule.getMayAttributeTypes();
+        List<MutableAttributeTypeImpl> may = dITContentRule.getMayAttributeTypes();
 
         if ( ( may != null ) && ( may.size() > 0 ) )
         {
@@ -279,7 +279,7 @@ public final class DescriptionUtils
             getQDStrings( buf, may );
         }
 
-        List<AttributeType> not = dITContentRule.getNotAttributeTypes();
+        List<MutableAttributeTypeImpl> not = dITContentRule.getNotAttributeTypes();
 
         if ( ( not != null ) && ( not.size() > 0 ) )
         {
@@ -500,7 +500,7 @@ public final class DescriptionUtils
         }
 
         buf.append( " APPLIES " );
-        List<AttributeType> attributeTypes = matchingRuleUse.getApplicableAttributes();
+        List<MutableAttributeTypeImpl> attributeTypes = matchingRuleUse.getApplicableAttributes();
 
         if ( attributeTypes.size() == 1 )
         {
@@ -513,7 +513,7 @@ public final class DescriptionUtils
 
             boolean isFirst = true;
 
-            for ( AttributeType attributeType : attributeTypes )
+            for ( MutableAttributeTypeImpl attributeType : attributeTypes )
             {
                 if ( isFirst )
                 {
@@ -592,11 +592,11 @@ public final class DescriptionUtils
         buf.append( '\n' );
 
         buf.append( " MUST\n" );
-        List<AttributeType> must = nameForm.getMustAttributeTypes();
+        List<MutableAttributeTypeImpl> must = nameForm.getMustAttributeTypes();
 
         getQDStrings( buf, must );
 
-        List<AttributeType> may = nameForm.getMayAttributeTypes();
+        List<MutableAttributeTypeImpl> may = nameForm.getMayAttributeTypes();
 
         if ( ( may != null ) && ( may.size() > 0 ) )
         {
@@ -702,7 +702,7 @@ public final class DescriptionUtils
             buf.append( '\n' );
         }
 
-        List<AttributeType> must = objectClass.getMustAttributeTypes();
+        List<MutableAttributeTypeImpl> must = objectClass.getMustAttributeTypes();
 
         if ( ( must != null ) && ( must.size() > 0 ) )
         {
@@ -710,7 +710,7 @@ public final class DescriptionUtils
             getQDStrings( buf, must );
         }
 
-        List<AttributeType> may = objectClass.getMayAttributeTypes();
+        List<MutableAttributeTypeImpl> may = objectClass.getMayAttributeTypes();
 
         if ( ( may != null ) && ( may.size() > 0 ) )
         {

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/EntityFactory.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/EntityFactory.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/EntityFactory.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/EntityFactory.java Sun Mar 20 21:22:39 2011
@@ -49,7 +49,7 @@ public interface EntityFactory
      * @return An AttributeType SchemaObject
      * @throws LdapException If the AttributeType is invalid
      */
-    AttributeType getAttributeType( SchemaManager schemaManager, Entry entry, Registries targetRegistries, String schemaName ) throws LdapException;
+    MutableAttributeTypeImpl getAttributeType( SchemaManager schemaManager, Entry entry, Registries targetRegistries, String schemaName ) throws LdapException;
 
     
     /**

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/MatchingRuleUse.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/MatchingRuleUse.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/MatchingRuleUse.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/MatchingRuleUse.java Sun Mar 20 21:22:39 2011
@@ -92,7 +92,7 @@ public class MatchingRuleUse extends Abs
     private List<String> applicableAttributeOids;
 
     /** The list of attributes types the matching rule applies to */
-    private List<AttributeType> applicableAttributes;
+    private List<MutableAttributeTypeImpl> applicableAttributes;
 
 
     /**
@@ -103,7 +103,7 @@ public class MatchingRuleUse extends Abs
         super( SchemaObjectType.MATCHING_RULE_USE, oid );
 
         applicableAttributeOids = new ArrayList<String>();
-        applicableAttributes = new ArrayList<AttributeType>();
+        applicableAttributes = new ArrayList<MutableAttributeTypeImpl>();
     }
 
 
@@ -127,7 +127,7 @@ public class MatchingRuleUse extends Abs
 
             if ( applicableAttributeOids != null )
             {
-                applicableAttributes = new ArrayList<AttributeType>( applicableAttributeOids.size() );
+                applicableAttributes = new ArrayList<MutableAttributeTypeImpl>( applicableAttributeOids.size() );
 
                 for ( String oid : applicableAttributeOids )
                 {
@@ -150,7 +150,7 @@ public class MatchingRuleUse extends Abs
     /**
      * @return The matchingRule's list of AttributeType OIDs the MRU applies to
      */
-    public List<AttributeType> getApplicableAttributes()
+    public List<MutableAttributeTypeImpl> getApplicableAttributes()
     {
         return applicableAttributes;
     }
@@ -180,7 +180,7 @@ public class MatchingRuleUse extends Abs
      *
      * @param applicableAttributes The AttributeType list
      */
-    public void setApplicableAttributes( List<AttributeType> applicableAttributes )
+    public void setApplicableAttributes( List<MutableAttributeTypeImpl> applicableAttributes )
     {
         if ( locked )
         {
@@ -194,7 +194,7 @@ public class MatchingRuleUse extends Abs
             // update the OIDS now
             applicableAttributeOids.clear();
 
-            for ( AttributeType at : applicableAttributes )
+            for ( MutableAttributeTypeImpl at : applicableAttributes )
             {
                 applicableAttributeOids.add( at.getOid() );
             }
@@ -226,7 +226,7 @@ public class MatchingRuleUse extends Abs
      *
      * @param attributeType A matchingRule's AttributeType the MRU applies to
      */
-    public void addApplicableAttribute( AttributeType attributeType )
+    public void addApplicableAttribute( MutableAttributeTypeImpl attributeType )
     {
         if ( locked )
         {
@@ -279,7 +279,7 @@ public class MatchingRuleUse extends Abs
         }
 
         // Copy the APPLIES list (will be empty)
-        copy.applicableAttributes = new ArrayList<AttributeType>();
+        copy.applicableAttributes = new ArrayList<MutableAttributeTypeImpl>();
 
         return copy;
     }
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultEntryAttribute.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultEntryAttribute.java Sun Mar 20 21:22:39 2011
@@ -31,7 +31,7 @@ import org.apache.directory.shared.i18n.
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.exception.LdapInvalidAttributeValueException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.SyntaxChecker;
 import org.apache.directory.shared.util.Strings;
 import org.apache.directory.shared.util.Unicode;
@@ -53,7 +53,7 @@ public class DefaultEntryAttribute imple
     private static final Logger LOG = LoggerFactory.getLogger( DefaultEntryAttribute.class );
 
     /** The associated AttributeType */
-    private AttributeType attributeType;
+    private MutableAttributeTypeImpl attributeType;
     
     /** The set of contained values */
     private Set<Value<?>> values = new LinkedHashSet<Value<?>>();
@@ -74,7 +74,7 @@ public class DefaultEntryAttribute imple
     //-------------------------------------------------------------------------
     // Helper methods
     //-------------------------------------------------------------------------
-    private Value<String> createStringValue( AttributeType attributeType, String value )
+    private Value<String> createStringValue( MutableAttributeTypeImpl attributeType, String value )
     {
         Value<String> stringValue = null;
         
@@ -109,7 +109,7 @@ public class DefaultEntryAttribute imple
     }
 
 
-    private Value<byte[]> createBinaryValue( AttributeType attributeType, byte[] value )
+    private Value<byte[]> createBinaryValue( MutableAttributeTypeImpl attributeType, byte[] value )
     {
         Value<byte[]> binaryValue = null;
         
@@ -161,7 +161,7 @@ public class DefaultEntryAttribute imple
     /**
      * Create a new instance of a EntryAttribute, without ID nor value.
      */
     /* No qualifier */ DefaultEntryAttribute( AttributeType attributeType, String upId, String normId, boolean isHR, int hashCode, Value<?>... values)
     {
         this.attributeType = attributeType;
         this.upId = upId;
@@ -184,7 +184,7 @@ public class DefaultEntryAttribute imple
      * 
      * @param attributeType the attributeType for the empty attribute added into the entry
      */
-    public DefaultEntryAttribute( AttributeType attributeType )
+    public DefaultEntryAttribute( MutableAttributeTypeImpl attributeType )
     {
         if ( attributeType == null )
         {
@@ -212,7 +212,7 @@ public class DefaultEntryAttribute imple
      * @param upId the ID for the added attributeType
      * @param attributeType the added AttributeType
      */
-    public DefaultEntryAttribute( String upId, AttributeType attributeType )
+    public DefaultEntryAttribute( String upId, MutableAttributeTypeImpl attributeType )
     {
         if ( attributeType == null ) 
         {
@@ -270,7 +270,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType The attributeType added on creation
      * @param vals The added value for this attribute
      */
-    public DefaultEntryAttribute( AttributeType attributeType, String... vals )
+    public DefaultEntryAttribute( MutableAttributeTypeImpl attributeType, String... vals )
     {
         this( null, attributeType, vals );
     }
@@ -283,7 +283,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType The attributeType added on creation
      * @param vals the added values for this attribute
      */
-    public DefaultEntryAttribute( String upId, AttributeType attributeType, String... vals )
+    public DefaultEntryAttribute( String upId, MutableAttributeTypeImpl attributeType, String... vals )
     {
         if ( attributeType == null )
         {
@@ -311,7 +311,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType the attribute type according to the schema
      * @param vals an initial set of values for this attribute
      */
-    public DefaultEntryAttribute( String upId, AttributeType attributeType, Value<?>... vals )
+    public DefaultEntryAttribute( String upId, MutableAttributeTypeImpl attributeType, Value<?>... vals )
     {
         if ( attributeType == null )
         {
@@ -336,7 +336,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType the attribute type according to the schema
      * @param vals an initial set of values for this attribute
      */
-    public DefaultEntryAttribute( AttributeType attributeType, Value<?>... vals )
+    public DefaultEntryAttribute( MutableAttributeTypeImpl attributeType, Value<?>... vals )
     {
         this( null, attributeType, vals );
     }
@@ -368,7 +368,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType The attributeType added on creation
      * @param vals The value for the added attribute
      */
-    public DefaultEntryAttribute( AttributeType attributeType, byte[]... vals )
+    public DefaultEntryAttribute( MutableAttributeTypeImpl attributeType, byte[]... vals )
     {
         this( null, attributeType, vals );
     }
@@ -381,7 +381,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType the AttributeType to be added
      * @param vals the values for the added attribute
      */
-    public DefaultEntryAttribute( String upId, AttributeType attributeType, byte[]... vals )
+    public DefaultEntryAttribute( String upId, MutableAttributeTypeImpl attributeType, byte[]... vals )
     {
         if ( attributeType == null )
         {
@@ -403,7 +403,7 @@ public class DefaultEntryAttribute imple
      * @param attributeType The attribute's type 
      * @param attribute The attribute to be copied
      */
-    public DefaultEntryAttribute( AttributeType attributeType, EntryAttribute attribute )
+    public DefaultEntryAttribute( MutableAttributeTypeImpl attributeType, EntryAttribute attribute )
     {
         // Copy the common values. isHR is only available on a ServerAttribute 
         this.attributeType = attributeType;
@@ -667,7 +667,7 @@ public class DefaultEntryAttribute imple
     /**
      * Check that the upId is either a name or the OID of a given AT
      */
-    private boolean areCompatible( String id, AttributeType attributeType )
+    private boolean areCompatible( String id, MutableAttributeTypeImpl attributeType )
     {
         // First, get rid of the options, if any
         int optPos = id.indexOf( ";" );
@@ -712,7 +712,7 @@ public class DefaultEntryAttribute imple
      * @param upId The attribute ID
      * @param attributeType The associated attributeType
      */
-    public void setUpId( String upId, AttributeType attributeType )
+    public void setUpId( String upId, MutableAttributeTypeImpl attributeType )
     {
         String trimmed = Strings.trim(upId);
 
@@ -2126,7 +2126,7 @@ public class DefaultEntryAttribute imple
      *
      * @return the attributeType associated with this entry attribute
      */
-    public AttributeType getAttributeType()
+    public MutableAttributeTypeImpl getAttributeType()
     {
         return attributeType;
     }
@@ -2144,7 +2144,7 @@ public class DefaultEntryAttribute imple
      *
      * @param attributeType the attributeType associated with this entry attribute
      */
-    public void setAttributeType( AttributeType attributeType )
+    public void setAttributeType( MutableAttributeTypeImpl attributeType )
     {
         if ( attributeType == null )
         {
@@ -161,7 +161,7 @@ public class DefaultEntryAttribute imple
      * Create a new instance of a EntryAttribute, without ID nor value.
      */
-    /* No qualifier */ DefaultEntryAttribute( AttributeType attributeType, String upId, String normId, boolean isHR, int hashCode, Value<?>... values)
+    /* No qualifier */ DefaultEntryAttribute( MutableAttributeTypeImpl attributeType, String upId, String normId, boolean isHR, int hashCode, Value<?>... values)
     {
         this.attributeType = attributeType;

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultModification.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/DefaultModification.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================
--- directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryUtils.java (original)
+++ directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/EntryUtils.java Sun Mar 20 21:22:39 2011
@@ -21,7 +21,7 @@ package org.apache.directory.shared.ldap
 
 import org.apache.directory.shared.i18n.I18n;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.AttributeType;
+import org.apache.directory.shared.ldap.model.schema.MutableAttributeTypeImpl;
 import org.apache.directory.shared.ldap.model.schema.AbstractLdapComparator;
 import org.apache.directory.shared.ldap.model.schema.MutableLdapSyntaxImpl;
 import org.apache.directory.shared.ldap.model.schema.MutableMatchingRuleImpl;
@@ -41,7 +41,7 @@ public class EntryUtils
     /**
      * A local Syntax class for tests
      */
-    static class AT extends AttributeType
+    static class AT extends MutableAttributeTypeImpl
     {
         private static final long serialVersionUID = 0L;
 
@@ -93,9 +93,9 @@ public class EntryUtils
         }
     }
 
     /* no protection*/ static AttributeType getCaseIgnoringAttributeNoNumbersType()
     {
-        AttributeType attributeType = new AttributeType( "1.1.3.1" );
+        MutableAttributeTypeImpl attributeType = new MutableAttributeTypeImpl( "1.1.3.1" );
         MutableLdapSyntaxImpl syntax = new MutableLdapSyntaxImpl( "1.1.1.1", "", true );
 
         syntax.setSyntaxChecker( new AbstractSyntaxChecker( "1.1.2.1" )
@@ -176,9 +176,9 @@ public class EntryUtils
     }
 
 
     /* no protection*/ static AttributeType getIA5StringAttributeType()
     {
-        AttributeType attributeType = new AttributeType( "1.1" );
+        MutableAttributeTypeImpl attributeType = new MutableAttributeTypeImpl( "1.1" );
         attributeType.addName( "1.1" );
         MutableLdapSyntaxImpl syntax = new MutableLdapSyntaxImpl( "1.1.1", "", true );
 
@@ -224,9 +224,9 @@ public class EntryUtils
     }
 
 
     /* No protection */ static AttributeType getBytesAttributeType()
     {
-        AttributeType attributeType = new AttributeType( "1.2" );
+        MutableAttributeTypeImpl attributeType = new MutableAttributeTypeImpl( "1.2" );
         MutableLdapSyntaxImpl syntax = new MutableLdapSyntaxImpl( "1.2.1", "", true );
 
         syntax.setSyntaxChecker( new AbstractSyntaxChecker( "1.2.1" )
@@ -93,9 +93,9 @@ public class EntryUtils
     }
 
-    /* no protection*/ static AttributeType getCaseIgnoringAttributeNoNumbersType()
+    /* no protection*/ static MutableAttributeTypeImpl getCaseIgnoringAttributeNoNumbersType()
     {
@@ -176,9 +176,9 @@ public class EntryUtils
 
 
-    /* no protection*/ static AttributeType getIA5StringAttributeType()
+    /* no protection*/ static MutableAttributeTypeImpl getIA5StringAttributeType()
     {
@@ -224,9 +224,9 @@ public class EntryUtils
 
 
-    /* No protection */ static AttributeType getBytesAttributeType()
+    /* No protection */ static MutableAttributeTypeImpl getBytesAttributeType()
     {

Modified: directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/ImmutableEntry.java
URL: http://svn.apache.org/viewvc/directory/shared/branches/akarasulu/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/entry/ImmutableEntry.java?rev=1083574&r1=1083573&r2=1083574&view=diff
==============================================================================